@@ -5,6 +5,9 @@ from matplotlib.gridspec import GridSpec
 import sys
 import pandas as pd
 
+import pyemission as pe
+
+
 # generic vehicle class
 class Car:
 
@@ -30,14 +33,20 @@ class Car:
         print('Loading Data...\n')
         df = Util.read_data(excel_file_name, sheet_name)
         vehicle = df.vehicle_type[0]
+        
+        # find the path of the 'db.pkl' to load it
+        path = pe.__file__
+        length = len('__init__.py')
+        path = path[:-length]
+        db_path = path + 'db.pkl'
         if vehicle == 'Light commercial truck' :
             try:
-                df_emission_rate = pickle.load(open('db.pkl','rb'))[0]
+                df_emission_rate = pickle.load(open(db_path,'rb'))[0]
             except:
                 print('Could not load the file: db.pkl\nMake sure the working directory contains this file.')
         else:
             try:
-                df_emission_rate = pickle.load(open('db.pkl','rb'))[1]
+                df_emission_rate = pickle.load(open(db_path,'rb'))[1]
             except:
                 print('Could not load the file: db.pkl\nMake sure the working directory contains this file.')
         
